==> xmonad-0.13-1-i686.pkg.tar.xz: usr/share/haskell/register/xmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xmonad
version: 0.13
id: xmonad-0.13-AkZSJ2Rx90ADXWeABBYMsj
key: xmonad-0.13-AkZSJ2Rx90ADXWeABBYMsj
license: BSD3
maintainer: xmonad@haskell.org
homepage: http://xmonad.org
synopsis: A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from
    the keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other
    extensions, may be written by the user in config files. Layouts are
    applied dynamically, and different layouts may be used on each
    workspace. Xinerama is fully supported, allowing windows to be tiled
    on several screens.
category: System
author: Spencer Janssen
exposed: True
exposed-modules:
    XMonad XMonad.Main XMonad.Core XMonad.Config XMonad.Layout
    XMonad.ManageHook XMonad.Operations XMonad.StackSet
hidden-modules: Paths_xmonad
abi: 6d41b444be858b73dec9ca98eb995885
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/xmonad-0.13
library-dirs: /usr/lib/ghc-8.0.1/site-local/xmonad-0.13
data-dir: /usr/share/i386-linux-ghc-8.0.1/xmonad-0.13
hs-libraries: HSxmonad-0.13-AkZSJ2Rx90ADXWeABBYMsj
depends:
    X11-1.8-BsdbKLLeIRPK4Le9AQbJ1X base-4.9.0.0 containers-0.5.7.1
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr directory-1.2.6.2
    extensible-exceptions-0.1.1.4-3h0ykvvAO915cRhUyj3rRV
    filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM process-1.4.2.0
    setlocale-1.0.0.4-EUtO5CfNQTBH7QTFQEDDaI unix-2.7.2.0
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html: /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-0.13-5-i686.pkg.tar.xz: usr/share/haskell/register/xmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xmonad
version: 0.13
id: xmonad-0.13-9ZasjWuCEP32C5g3bMqR0q
key: xmonad-0.13-9ZasjWuCEP32C5g3bMqR0q
license: BSD3
maintainer: xmonad@haskell.org
homepage: http://xmonad.org
synopsis: A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from
    the keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other
    extensions, may be written by the user in config files. Layouts are
    applied dynamically, and different layouts may be used on each
    workspace. Xinerama is fully supported, allowing windows to be tiled
    on several screens.
category: System
author: Spencer Janssen
exposed: True
exposed-modules:
    XMonad XMonad.Main XMonad.Core XMonad.Config XMonad.Layout
    XMonad.ManageHook XMonad.Operations XMonad.StackSet
hidden-modules: Paths_xmonad
abi: 7a035f704c557c7a8b3282df8fbd7903
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/xmonad-0.13
library-dirs: /usr/lib/ghc-8.0.2/site-local/xmonad-0.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/xmonad
hs-libraries: HSxmonad-0.13-9ZasjWuCEP32C5g3bMqR0q
depends:
    X11-1.8-189f0mYhex5EKHd6fv5Psu base-4.9.1.0 containers-0.5.7.1
    data-default-0.7.1.1-BNa3MzH41nV77yjS9K2Umq directory-1.3.0.0
    extensible-exceptions-0.1.1.4-IyAM3ARTqH7BVZ5oHMMtXH
    filepath-1.4.1.1 mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 process-1.4.3.0
    setlocale-1.0.0.5-8ADebeL8z2H6tF1V4IASwV unix-2.7.2.1
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
haddock-interfaces: /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html: /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
